@@ -103,7 +103,7 @@ namespace Breeze
         MenuBarItem_MarginHeight = 6,
 
         // scrollbars
-        ScrollBar_Extend = 20,
+        ScrollBar_Extend = 21,
         ScrollBar_SliderWidth = 6,
         ScrollBar_MinSliderHeight = 20,
         ScrollBar_NoButtonHeight = (ScrollBar_Extend-ScrollBar_SliderWidth)/2,
@@ -170,6 +170,26 @@ namespace Breeze
 
     };
 
+    //* standard pen widths
+    namespace PenWidth
+    {
+        /* Using 1 instead of slightly more than 1 causes symbols drawn with
+         * pen strokes to look skewed. The exact amount added does not matter
+         * as long as it isn't too visible.
+         */
+        // The standard pen stroke width for symbols.
+        static constexpr qreal Symbol = 1.01;
+
+        // The standard pen stroke width for frames.
+        static constexpr int Frame = 1;
+
+        // The standard pen stroke width for shadows.
+        static constexpr int Shadow = 1;
+        
+        // A value for pen width arguments to make it clear that there is no pen stroke
+        static constexpr int NoPen = 0;
+    }
+    
     //* animation mode
     enum AnimationMode
     {
@@ -234,7 +254,8 @@ namespace Breeze
         ArrowUp,
         ArrowDown,
         ArrowLeft,
-        ArrowRight
+        ArrowRight,
+        ArrowDown_Small,
     };
 
     //* button type
