@@ -165,7 +165,7 @@ namespace Breeze
         void renderDebugFrame( QPainter*, const QRect& ) const;
 
         //* focus rect
-        void renderFocusRect( QPainter*, const QRect&, const QColor&, const QColor& outline = QColor(), Sides = 0 ) const;
+        void renderFocusRect( QPainter*, const QRect&, const QColor&, const QColor& outline = QColor(), Sides = {} ) const;
 
         //* focus line
         void renderFocusLine( QPainter*, const QRect&, const QColor& ) const;
@@ -242,6 +242,9 @@ namespace Breeze
         void renderToolBarHandle( QPainter* painter, const QRect& rect, const QColor& color ) const
         { return renderProgressBarGroove( painter, rect, color ); }
 
+        //* separator between scrollbar and contents
+        void renderScrollBarBorder( QPainter*, const QRect&, const QColor& ) const;
+
         //* tabbar tab
         void renderTabBarTab( QPainter*, const QRect&, const QColor& color, const QColor& outline, Corners ) const;
 
@@ -251,6 +254,12 @@ namespace Breeze
         //* generic button (for mdi decorations, tabs and dock widgets)
         void renderDecorationButton( QPainter*, const QRect&, const QColor&, ButtonType, bool inverted ) const;
 
+        //* generic shadow for rounded rectangles
+        void renderRoundedRectShadow ( QPainter*, const QRectF&, const QColor&, qreal radius = Metrics::Frame_FrameRadius - 0.5 ) const;
+        
+        //* generic shadow for ellipses
+        void renderEllipseShadow( QPainter*, const QRectF&, const QColor& ) const;
+        
         //@}
 
         //*@name compositing utilities
@@ -305,17 +314,24 @@ namespace Breeze
         //@}
 
         //* frame radius
-        qreal frameRadius( qreal bias = 0 ) const
-        { return qMax( qreal( Metrics::Frame_FrameRadius ) - 0.5 + bias, 0.0 ); }
+        constexpr qreal frameRadius( const int penWidth = PenWidth::NoPen, const qreal bias = 0 ) const
+        { return qMax( Metrics::Frame_FrameRadius - (0.5 * penWidth) + bias, 0.0 ); }
+        
+        //* frame radius with new pen width
+        constexpr qreal frameRadiusForNewPenWidth( const qreal oldRadius, const int penWidth ) const
+        { return qMax( oldRadius - (0.5 * penWidth), 0.0 ); }
+        
+        //* return a QRectF with the appropriate size for a rectangle with a pen stroke
+        QRectF strokedRect( const QRectF &rect, const int penWidth = PenWidth::Frame ) const;
+        
+        //* return a QRectF with the appropriate size for a rectangle with a pen stroke
+        QRectF strokedRect( const QRect &rect, const int penWidth = PenWidth::Frame ) const;
 
         protected:
 
         //* initialize
         void init();
 
-        //* return rectangle for widgets shadow, offset depending on light source
-        QRectF shadowRect( const QRectF& ) const;
-
         //* return rounded path in a given rect, with only selected corners rounded, and for a given radius
         QPainterPath roundedPath( const QRectF&, Corners, qreal ) const;
 
