@@ -1,6 +1,6 @@
 /*************************************************************************
  * Copyright (C) 2014 by Hugo Pereira Da Costa <hugo.pereira@free.fr>    *
- * Copyright (C) 2018 by Vlad Zagorodniy <vladzzag@gmail.com>            *
+ * Copyright (C) 2018 by Vlad Zagorodniy <vlad.zahorodnii@kde.org>       *
  *                                                                       *
  * This program is free software; you can redistribute it and/or modify  *
  * it under the terms of the GNU General Public License as published by  *
@@ -397,7 +397,7 @@ namespace Breeze
 
         /**
         shadow atom and property specification available at
-        http://community.kde.org/KWin/Shadow
+        https://community.kde.org/KWin/Shadow
         */
 
         // create atom
@@ -457,7 +457,13 @@ namespace Breeze
 
         // create image from QPixmap and assign to pixmap
         QImage image( source.toImage() );
+
+
+        #if QT_VERSION >= 0x051000
+        xcb_put_image( Helper::connection(), XCB_IMAGE_FORMAT_Z_PIXMAP, pixmap, _gc, image.width(), image.height(), 0, 0, 0, 32, image.sizeInBytes(), image.constBits());
+        #else
         xcb_put_image( Helper::connection(), XCB_IMAGE_FORMAT_Z_PIXMAP, pixmap, _gc, image.width(), image.height(), 0, 0, 0, 32, image.byteCount(), image.constBits());
+        #endif
 
         return pixmap;
 
@@ -473,7 +479,7 @@ namespace Breeze
         if( !widget ) return false;
 
         /*
-        From bespin code. Supposibly prevent playing with some 'pseudo-widgets'
+        From bespin code. Supposedly prevent playing with some 'pseudo-widgets'
         that have winId matching some other -random- window
         */
         if( !(widget->testAttribute(Qt::WA_WState_Created) && widget->internalWinId() ))
@@ -585,9 +591,8 @@ namespace Breeze
 
         if (widget->inherits("QBalloonTip")) {
             // Balloon tip needs special margins to deal with the arrow.
-            int top = 0;
-            int bottom = 0;
-            widget->getContentsMargins(nullptr, &top, nullptr, &bottom);
+            int top = widget->contentsMargins().top();
+            int bottom = widget->contentsMargins().bottom();
 
             // Need to decrement default size further due to extra hard coded round corner.
 #if BREEZE_USE_KDE4
