@@ -150,7 +150,7 @@ namespace Breeze
         if( _enabled != value )
         {
             _enabled = value;
-            if( _enabled ) clearSplitter();
+            if( !_enabled ) clearSplitter();
         }
     }
 
@@ -352,20 +352,17 @@ namespace Breeze
         // release mouse
         if( mouseGrabber() == this ) releaseMouse();
 
-        // hide
-        parentWidget()->setUpdatesEnabled(false);
-        hide();
-        parentWidget()->setUpdatesEnabled(true);
-
         // send hover event
         if( _splitter )
         {
-            QHoverEvent hoverEvent(
-                qobject_cast<QSplitterHandle*>(_splitter.data()) ? QEvent::HoverLeave : QEvent::HoverMove,
-                _splitter.data()->mapFromGlobal(QCursor::pos()), _hook);
-            QCoreApplication::sendEvent( _splitter.data(), &hoverEvent );
+            // SplitterProxy intercepts HoverLeave/HoverMove events to _splitter,
+            // but this is meant to reach it directly. Unset _splitter to stop interception.
+            auto splitter = _splitter;
             _splitter.clear();
-
+            QHoverEvent hoverEvent(
+                qobject_cast<QSplitterHandle*>(splitter.data()) ? QEvent::HoverLeave : QEvent::HoverMove,
+                splitter.data()->mapFromGlobal(QCursor::pos()), _hook);
+            QCoreApplication::sendEvent( splitter.data(), &hoverEvent );
         }
 
         // kill timer if any
@@ -375,6 +372,12 @@ namespace Breeze
             _timerId = 0;
         }
 
+        // hide
+        parentWidget()->setUpdatesEnabled(false);
+        // Note: This sends a synthetic mouse event to the widget below (to get focus), which might be
+        // another SplitterHandle, therefore enabling this SplitterProxy again!
+        hide();
+        parentWidget()->setUpdatesEnabled(true);
     }
 
 }
